#
# spec file for package libmtp
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define debug_package_requires libmtp8 = %{version}-%{release}

Name:           libmtp
Url:            http://sf.net/projects/libmtp
BuildRequires:  doxygen pkg-config
BuildRequires:  libusb-devel
License:        LGPLv2.1+
Group:          Productivity/Multimedia/Sound/Players
AutoReqProv:    on
Summary:        Commandline utilities for access to MTP Players
Version:        1.0.6
Release:        10.1
Source0:        %name-%version.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains binaries and documentation that allow accessto
USB based media players based on the MTP (Media TransferProtocol)
authored by Microsoft.

Common devices using this technology are Creative Zen, iRiver, Samsung
and others.



Authors:
--------
    Richard Low <richard@wentnet.com>
    Linus Walleij <triad@df.lth.se>
    
    based on code by:
    Mariusz Woloszyn <emsi@ipartners.pl>
    Marcus Meissner <marcus@jet.franken.de>

%package -n libmtp8
License:        LGPLv2.1+
Summary:        Library for accessing MTP Players
Group:          Productivity/Multimedia/Sound/Players

%description -n libmtp8
This package contain the libraries that allow access to USB based media
players based on the MTP (Media TransferProtocol) authored by
Microsoft.

Common devices using this technology are Creative Zen, iRiver, Samsung
and others.



Authors:
--------
    Richard Low <richard@wentnet.com>
    Linus Walleij <triad@df.lth.se>
    
    based on code by:
    Mariusz Woloszyn <emsi@ipartners.pl>
    Marcus Meissner <marcus@jet.franken.de>

%package -n mtp-tools
License:        LGPLv2.1+
Summary:        Commandline utilities for access to MTP Players
Group:          Productivity/Multimedia/Sound/Players

%package devel
License:        LGPLv2.1+
Summary:        Development files for access to MTP Player library
Group:          Development/Libraries/Other
Requires:       libmtp8 = %version
Requires:       libusb-devel

%description devel
This package contains the development headers for the libmtp library
that allows access to USB based media players based on the MTP (Media
Transfer Protocol) authored by Microsoft.



Authors:
--------
    Richard Low <richard@wentnet.com>
    Linus Walleij <triad@df.lth.se>
    
    based on code by:
    Mariusz Woloszyn <emsi@ipartners.pl>
    Marcus Meissner <marcus@jet.franken.de>

%description -n mtp-tools
This package contains binaries that allow command line access to USB
based media players based on the MTP (Media TransferProtocol) authored
by Microsoft. For graphical user interfaces use Amarok or Banshee.



Authors:
--------
    Richard Low <richard@wentnet.com>
    Linus Walleij <triad@df.lth.se>
    
    based on code by:
    Mariusz Woloszyn <emsi@ipartners.pl>
    Marcus Meissner <marcus@jet.franken.de>

%prep
%setup -q

%build
%configure --disable-static --enable-doxygen
make

%install
make install DESTDIR=$RPM_BUILD_ROOT
install -d $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/
install -c -m 644 libmtp.fdi $RPM_BUILD_ROOT/usr/share/hal/fdi/information/20thirdparty/10-usb-music-players-libmtp.fdi
rm -rf $RPM_BUILD_ROOT/usr/share/doc/libmtp*
rm -rf $RPM_BUILD_ROOT/%{_libdir}/*.la

# copy over the mtp rules, but leave out mtp-probe
grep -v mtp-probe $RPM_BUILD_ROOT/lib/udev/rules.d/libmtp.rules > $RPM_BUILD_ROOT/lib/udev/rules.d/39-libmtp.rules
rm $RPM_BUILD_ROOT/lib/udev/rules.d/libmtp.rules

# calling this for all unknown devices crashes some color management devices and probably others.
rm $RPM_BUILD_ROOT/lib/udev/mtp-probe

%post -n libmtp8 -p /sbin/ldconfig

%postun -n libmtp8 -p /sbin/ldconfig

%files -n mtp-tools
%defattr(-, root, root)
%{_prefix}/bin/*

%files -n libmtp8
%defattr(-, root, root)
%doc COPYING README ChangeLog AUTHORS
%{_libdir}/lib*.so.*
%dir /usr/share/hal
%dir /usr/share/hal/fdi
%dir /usr/share/hal/fdi/information
%dir /usr/share/hal/fdi/information/20thirdparty/
/usr/share/hal/fdi/information/20thirdparty/10-usb-music-players-libmtp.fdi
%dir /lib/udev
#/lib/udev/mtp-probe
%dir /lib/udev/rules.d
%config /lib/udev/rules.d/39-libmtp.rules

%files devel
%defattr(-, root, root)
%doc doc/html TODO
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/libmtp.pc
%{_prefix}/include/libmtp.h

%changelog
* Wed Apr 25 2012 meissner@suse.com
- remove mtp-probe rule from udev rules too. bnc#700243,bnc#759344
* Thu Mar 29 2012 meissner@suse.de
- disabe mtp-probe as it crashes colorimeters etc. bnc#700243 / bnc#739071
* Tue Feb 15 2011 meissner@suse.de
- updated to 1.0.6
  * even less aggressive mtp probing (not detecting nearly all
    devices as MTP) bnc#668986
  * some more USB ids
* Tue Jan 25 2011 meissner@suse.de
- do not greedily match all PTP cameras in the udev rules.
* Mon Jan 10 2011 meissner@suse.de
- updated to 1.0.4 incremental release
  * new ids
  * bugfixes
  * new udev rules for new udev
* Sun May 23 2010 meissner@novell.com
- updated to 1.0.3 incremental release
  * some new ids
  * some smaller bugfixes
- buildrequre pkg-config
* Wed Apr 28 2010 meissner@suse.de
- updated to intermediate snapshot
  * Samsung fixes and new ids
  * various small bugfixes
* Mon Feb  1 2010 meissner@suse.de
- updated to 1.0.2 bugfix release
  * new ids: Samsung, Archos, Blackberry, ...
  * bugfixes
* Wed Sep 16 2009 meissner@suse.de
- updated to 1.0.1 bugfix release
  * last patches included
  * some more bug flags for devices
* Sat Sep  5 2009 meissner@suse.de
- bugfixes to "fast metadata loading" method
* Tue Aug  4 2009 meissner@suse.de
- upgraded to 1.0.0 release
  * More USB ids
  * libmtp.so.8.3.0 library interface
  * New functions:
    LIBMTP_Get_File_To_Handler
    LIBMTP_Send_File_From_Handler
    LIBMTP_Get_Track_To_Handler
    LIBMTP_Send_Track_From_Handler
    functions to get/send files/tracks from/to handler functions.
    External handling of individual properties:
    LIBMTP_Is_Property_Supported to check if a certain property is
    supported on a certain device.
    LIBMTP_Get_Allowed_Property_Values to get alowed range/enum of a
    property value.
    LIBMTP_Get_Representative_Sample_Format will now get the size
    parameter to allow us to determine the maximum size for a
    representative sample.
  * Added modificationdate to file and track structs.
  * Added LIBMTP_FILETYPE_ALBUM and LIBMTP_FILETYPE_PLAYLIST filetypes.
  * Numerous Windows portability fixes.
  * Marcus Meissner rewrote the PTP object handling and metadata caching
    functions from libgphoto2 and fixed up the ugly largefile handling.
  * Various minor bug fixes.
* Tue Mar 17 2009 meissner@suse.de
- upgraded to 0.3.7
  * compatible library interface libmtp.8.2.2
  * stores albums and playlists in the default
    music folder if no default folder for albums resp.
    playlists has been detected.
  * an error report from RedHat BZ
    http://bugzilla.redhat.com/show_bug.cgi?id=485627
    led to strange code for detecting anonymous OGG files
    being rewritten to handle NULL filenames and filenames
    that do not exceed 4 chars.
  * patch from Marcus to fix an issue
    with retransmit originally reported by Florent Pillet.
  * discovered a new device that cannot even
    read out battery level but still claims to be able to.
- upgraded to 0.3.6
  * Compatible API libmtp.so.8.2.1
  * Several bug fixes to the examples
  * Improved Windows and *BSD support
  * Proper device flags to handle Toshiba players (hopefully)
  * New devices and flag settings
  * Nothing new from a programmers point of view
- upgraded to 0.3.5
  * Bumped soname to libmtp.so.8.2.0
  - Only interface change:
  * Change metadata const*const to *const to allow playlist_id to be
    modified by LIBMTP_Update_Playlist. Shouldn't affect any code out
    there really.
  - New features and bugfixes:
  * Allow for playlists with zero tracks on them (also in update).
  * Get folders to a flat list and we get O(n) searching instead of
    the previous O(n^2) algorithm! The rest is janitorial changes.
* Mon Dec 15 2008 meissner@suse.de
- detach the Cowon iAudio 7 from usb-storage on start to make it work
  bnc#457931
* Fri Nov  7 2008 meissner@suse.de
- upgraded to 0.3.4
  * Check propdesc before setting props in create_new_abstract_list() (Richard)
  * Fix several bugs in Ogg filetype support (Alvin)
  * New flag for broken handling of PTP_OPC_DateModified, tag all
  SanDisk devices with this flag. Bug appeared in them. (Linus)
  * Sync in upstream updates to PTP baseline (Linus)
  * Detect and warn on broken OPLs (Richard)
  * Fix the association type problem on LIBMTP_Create_Folder(). This
  caused folders not to work properly on some devices!! (Linus)
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Fri Sep 26 2008 meissner@suse.de
- upgraded to 0.3.3
  - lots of new ids
  - protocol bugfixes for Samsung and Creative devices
  - bugfixes
* Wed Aug 27 2008 meissner@suse.de
- let debuginfo require libmtp8
- disable static libs and .la files
* Tue Aug 26 2008 meissner@suse.de
- upgraded to 0.3.1
  - lots of new ids
  - sansa player handling better now
  - special playlist support for a subkind of devices
- commandline tools now live in mtp-tools, libmtp is empty.
* Tue Jun 24 2008 meissner@suse.de
- upgraded to 0.3.0
  - new major version 8 due to API changes
  - new devices
  - lots of bugfixes
- libmtp7 renamed to libmtp8
- doxygen added as buildrequires
* Tue Mar 11 2008 meissner@suse.de
- upgraded to 0.2.6.1
  - disabled debug
- info.bus -> info.subsystem in FDI file
* Mon Mar  3 2008 meissner@suse.de
- upgraded to 0.2.6
  - some new devices
  - bugfixes
  - remove LIBMTP_Set_Object_Parent function -> new major
* Wed Jan  9 2008 meissner@suse.de
- upgraded to 0.2.5
  - several new devices
  - code cleanups and bugfixes
* Mon Nov 26 2007 meissner@suse.de
- upgraded to 0.2.4
  - various bug fixes and new fixes
  - header-repairing for Zen devices
* Sun Oct 28 2007 meissner@suse.de
- --program-prefix=mtp- is needed.
* Fri Oct 26 2007 meissner@suse.de
- upgraded to 0.2.3
  - new devices added
  - varous bugfixes, speed ups
  - bumped so from 6 to 7
- split off libmtp7 package
* Mon Oct  8 2007 meissner@suse.de
- upgraded to 0.2.2
  - bugfixes, new devices, faster metadata read
* Fri Aug 10 2007 meissner@suse.de
- upgraded to 0.2.1 release
  - fixed for LFS support
* Sat Aug  4 2007 meissner@suse.de
- upgraded to 0.2.0 release
  - more USB ids
  - 64bit handling
* Thu Jul 26 2007 meissner@suse.de
- uprgaded to current CVS state
  - caching of fs and metadata
  - new devices
  - ptp reset binary
  - bugfixes
* Mon Jun  4 2007 stbinner@suse.de
- fix build requires for older distributions
* Wed May 16 2007 olh@suse.de
- Buildrequires libusb -> libusb-devel
  Remove unneded Requires libusb
  - devel package requires libusb-devel
* Tue Mar 27 2007 meissner@suse.de
- upstream 0.1.5
  - uses SetObjPropList for most devices
  - usb lowlevel communication fixes for
  stubborn devices
  - some new ids
* Wed Mar  7 2007 meissner@suse.de
- upstream 0.1.4
  - lots of bugfixes
  - multiple device handling
* Thu Feb  8 2007 dmueller@suse.de
- split into -devel subpackage
* Wed Jan 17 2007 meissner@suse.de
- upstream 0.1.3
  - bugfixes.
* Wed Jan 10 2007 meissner@suse.de
- use %%run_ldconfig in post/postun. (from rpmlint)
* Mon Jan  8 2007 meissner@suse.de
- Upgraded to 0.1.2:
  - new devices
  - lots of bugfixes, rewritten lowlevel
  communications layer.
* Sat Dec  2 2006 meissner@suse.de
- Upgraded to 0.1.0:
  - new devices
  - metadata, tracks, vcf handling
  - enhanced tools
  - HAL snippet
* Thu Sep 21 2006 meissner@suse.de
- Upgraded to 0.0.19:
  - formatting of devices added
  - lots of fixes
* Mon Aug 28 2006 meissner@suse.de
- Upgraded to 0.0.16
  - better handling of non-ascii filenames
  - handling of large files
* Wed Aug 23 2006 meissner@suse.de
- libmtp 0.0.13
  - Library to access MTP devices.
  - Small sample tools for accessing.
